package org.letouilleur.portlet;

import java.io.IOException;
import java.util.ArrayList;
import javax.portlet.GenericPortlet;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.portlet.MimeResponse;

import org.w3c.dom.Element;

import javax.portlet.*;

/**
 * A very simple Hello World Portlet that handles normal, maximized and help states.
 *
 * @author Nicolas Martignole
 */
public class TwitterPortlet01 extends GenericPortlet {

    private static final String NORMAL_VIEW = "/portlet01/normal.jsp";
    private static final String MAXIMIZED_VIEW = "/portlet01/maximized.jsp";

    private PortletRequestDispatcher normalView;
    private PortletRequestDispatcher maximizedView;

    private String myPublicScreenName = "";

    public void doView(RenderRequest request, RenderResponse response)
            throws PortletException, IOException {

        if (WindowState.MINIMIZED.equals(request.getWindowState())) {
            return;
        }


        // Set the last value of myPublicScreenName
        request.getPortletSession().setAttribute("myPublicScreenName",myPublicScreenName);

        if (WindowState.NORMAL.equals(request.getWindowState())) {
            normalView.include(request, response);
        } else {
            maximizedView.include(request, response);
        }


    }


    public void init(PortletConfig config) throws PortletException {
        super.init(config);
        normalView = config.getPortletContext().getRequestDispatcher(NORMAL_VIEW);
        maximizedView = config.getPortletContext().getRequestDispatcher(MAXIMIZED_VIEW);
    }

    public void destroy() {
        normalView = null;
        maximizedView = null;
        super.destroy();
    }

    /**
     * This method is executed when the user submit the Form.
     */
    @Override
    public void processAction(ActionRequest request, ActionResponse response) throws PortletException, IOException {
        java.util.List<String> tweets = new ArrayList<String>();
        tweets.add("Premier Tweet");
        tweets.add("Deuxime Tweet");
        tweets.add("Troisime Tweet");

        request.getPortletSession().setAttribute("tweets", tweets);

    }

    /**
     * This callback method is triggered when a "myEvent" JSR-286 event
     * is sent to the Portal.
     */
    @Override
    public void processEvent(EventRequest request, EventResponse response) {
        Event event = request.getEvent();
        if (event.getName().equals("myEvent")) {
            String payload = (String) event.getValue();
            //process payload here
            System.out.println("------------------------------------------------------");
            System.out.println(getClass().getName() + " received an event: " + payload);
            System.out.println("------------------------------------------------------");

            // Update the property, the Portal will then call the doView
            // to redisplay the page
            myPublicScreenName=payload;

        }
    }


}
