package org.letouilleur.portlet;

import javax.portlet.*;
import java.io.IOException;
import java.util.ArrayList;

/**
 * This simple Portlet demonstrates how to update the PortletPreferences
 * and also how to send a JSR-286 Event
 * http://touilleur-express.fr
 * User: nicolas
 * Date: 16 nov. 2009
 * Time: 09:55:38 in Thalys, heading to Devoxx !
 */
public class TwitterPortlet02 extends GenericPortlet {
    private static final String NORMAL_VIEW = "/portlet02/viewPortlet02.jsp";
    private static final String MAXIMIZED_VIEW = "/portlet02/viewPortlet02.jsp";

    private PortletRequestDispatcher normalView;
    private PortletRequestDispatcher maximizedView;

    public void doView(RenderRequest request, RenderResponse response)
            throws PortletException, IOException {

        if (WindowState.MINIMIZED.equals(request.getWindowState())) {
            return;
        }

        if (WindowState.NORMAL.equals(request.getWindowState())) {
            normalView.include(request, response);
        } else {
            maximizedView.include(request, response);
        }
    }

    @Override
    protected void doEdit(RenderRequest renderRequest, RenderResponse renderResponse) throws PortletException, IOException {
        renderResponse.setContentType(renderRequest.getResponseContentType());
        getPortletContext().getRequestDispatcher("/portlet02/editPublicRenderParameter.jsp").include(renderRequest, renderResponse);
    }


    public void init(PortletConfig config) throws PortletException {
        super.init(config);
        normalView = config.getPortletContext().getRequestDispatcher(NORMAL_VIEW);
        maximizedView = config.getPortletContext().getRequestDispatcher(MAXIMIZED_VIEW);
    }

    public void destroy() {
        normalView = null;
        maximizedView = null;
        super.destroy();
    }

    @Override
    public void processAction(ActionRequest request, ActionResponse response) throws PortletException, IOException {

        if (request.getPortletMode().equals(PortletMode.EDIT)) {
            sendActionEvent(request, response);
        }

        if (request.getPortletMode().equals(PortletMode.VIEW)) {
            fetchAndStoreListOfTweets(request);
        }

    }

    private void fetchAndStoreListOfTweets(ActionRequest request) {
        java.util.List<String> tweets = new ArrayList<String>();
        tweets.add("Premier Tweet");
        tweets.add("Deuxime Tweet");
        tweets.add("Troisime Tweet");
        tweets.add("4e Tweet");
        tweets.add("5e Tweet that is fun");
        request.getPortletSession().setAttribute("tweets", tweets);
    }

    private void sendActionEvent(ActionRequest request, ActionResponse response) throws PortletModeException, ReadOnlyException, IOException, ValidatorException {
        // retrieve parameters
        String screenName = request.getParameter("screenName");
        System.out.println("------------------------------------------------------");
        System.out.println("Setting twitter account value to: " + screenName);
        System.out.println("------------------------------------------------------");

        // Update this portlet preference
        PortletPreferences prefs=request.getPreferences();
        prefs.setValue("defaultScreenName",screenName);
        prefs.store();


        // Send an event
        response.setEvent("myEvent", screenName);

        // back to view mode
        response.setPortletMode(PortletMode.VIEW);
    }


}
